<?php
/**
 * Helper functions.
 *
 * @package Winsome
 */

if ( ! function_exists( 'winsome_get_slider_details' ) ) :

	/**
	 * Slider details.
	 *
	 * @since 1.0.0
	 *
	 * @return array Slider details.
	 */
	function winsome_get_slider_details() {

		$output = array();

		for ( $i = 1; $i <= 5 ; $i++ ) { 

			$slide_title 	= winsome_get_option('slide_'.$i.'_title');
			$slide_subtitle = winsome_get_option('slide_'.$i.'_subtitle');
			$slide_image 	= winsome_get_option('slider_'.$i.'_image');

			$cta_text = winsome_get_option('cta_text');
			$cta_url  = winsome_get_option('cta_url');

			$output[ $i ]['image_url'] = $slide_image;
			$output[ $i ]['title']     = $slide_title;
			$output[ $i ]['excerpt']   = $slide_subtitle;

			$output[ $i ]['cta_text']  = $cta_text;
			$output[ $i ]['cta_url']   = $cta_url;
		
		}

		return $output;
	}

endif;

if ( ! function_exists( 'winsome_get_the_excerpt' ) ) :

	/**
	 * Returns post excerpt.
	 *
	 * @since 1.0.0
	 *
	 * @param int     $length      Excerpt length in words.
	 * @param WP_Post $post_object The post object.
	 * @return string Post excerpt.
	 */
	function winsome_get_the_excerpt( $length = 0, $post_object = null ) {
		global $post;

		if ( is_null( $post_object ) ) {
			$post_object = $post;
		}

		$length = absint( $length );
		if ( 0 === $length ) {
			return;
		}



		$source_content = $post_object->post_content;

		if ( ! empty( $post_object->post_excerpt ) ) {
			$source_content = $post_object->post_excerpt;
		}

		$source_content = strip_shortcodes( $source_content );
		$trimmed_content = wp_trim_words( $source_content, $length, '...' );
		return $trimmed_content;
	}

endif;

if ( ! function_exists( 'winsome_fonts_url' ) ) :

	/**
	 * Register Google fonts.
	 *
	 * @since 1.0.0
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function winsome_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Open Sans, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'winsome' ) ) {
			$fonts[] = 'Open Sans:400,700,900,400italic,700italic,900italic';
		}
		/* translators: If there are characters in your language that are not supported by Open Sans, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'winsome' ) ) {
			$fonts[] = 'Raleway:400,500,700,900,400italic,700italic,900italic';
		}
		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}

endif;
