<?php
/**
 * Options.
 *
 * @package Winsome
 */

$default = winsome_get_default_theme_options();

// Add Theme Options Panel.
$wp_customize->add_panel( 'theme_option_panel',
	array(
		'title'      => __( 'Theme Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
	)
);

// Header Section.
$wp_customize->add_section( 'section_header',
	array(
		'title'      => __( 'Header Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting show_title.
$wp_customize->add_setting( 'show_title',
	array(
		'default'           => $default['show_title'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'show_title',
	array(
		'label'    => __( 'Show Site Title', 'winsome' ),
		'section'  => 'section_header',
		'type'     => 'checkbox',
		'priority' => 100,
	)
);

// Setting show_tagline.
$wp_customize->add_setting( 'show_tagline',
	array(
		'default'           => $default['show_tagline'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'show_tagline',
	array(
		'label'    => __( 'Show Tagline', 'winsome' ),
		'section'  => 'section_header',
		'type'     => 'checkbox',
		'priority' => 100,
	)
);

// Layout Section.
$wp_customize->add_section( 'section_layout',
	array(
		'title'      => __( 'Layout Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting global_layout.
$wp_customize->add_setting( 'global_layout',
	array(
		'default'           => $default['global_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_select',
	)
);
$wp_customize->add_control( 'global_layout',
	array(
		'label'    => __( 'Global Layout', 'winsome' ),
		'section'  => 'section_layout',
		'type'     => 'radio',
		'priority' => 100,
		'choices'  => array(
				'left-sidebar'  => esc_html__( 'Left Sidebar', 'winsome' ),
				'right-sidebar' => esc_html__( 'Right Sidebar', 'winsome' ),
				'no-sidebar'    => esc_html__( 'No Sidebar', 'winsome' ),
			),
	)
);

// Setting archive_layout.
$wp_customize->add_setting( 'archive_layout',
	array(
		'default'           => $default['archive_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_select',
	)
);
$wp_customize->add_control( 'archive_layout',
	array(
		'label'    => __( 'Archive Layout', 'winsome' ),
		'section'  => 'section_layout',
		'type'     => 'radio',
		'priority' => 100,
		'choices'  => array(
				'full'    => esc_html__( 'Full Post', 'winsome' ),
				'excerpt' => esc_html__( 'Post Excerpt', 'winsome' ),
			),
	)
);

// Setting excerpt_length.
$wp_customize->add_setting( 'excerpt_length',
	array(
		'default'           => $default['excerpt_length'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'excerpt_length',
	array(
		'label'       => __( 'Excerpt Length', 'winsome' ),
		'description' => __( 'in words', 'winsome' ),
		'section'     => 'section_layout',
		'type'        => 'number',
		'priority'    => 100,
		'input_attrs' => array( 'min' => 1, 'max' => 200, 'style' => 'width: 55px;' ),
	)
);

// Footer Section.
$wp_customize->add_section( 'section_footer',
	array(
		'title'      => __( 'Footer Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting copyright_text.
$wp_customize->add_setting( 'copyright_text',
	array(
		'default'           => $default['copyright_text'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'copyright_text',
	array(
		'label'    => __( 'Copyright Text', 'winsome' ),
		'section'  => 'section_footer',
		'type'     => 'text',
		'priority' => 100,
	)
);

// Breadcrumb Section.
$wp_customize->add_section( 'section_breadcrumb',
	array(
		'title'      => __( 'Breadcrumb Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting breadcrumb_type.
$wp_customize->add_setting( 'breadcrumb_type',
	array(
		'default'           => $default['breadcrumb_type'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_select',
	)
);
$wp_customize->add_control( 'breadcrumb_type',
	array(
		'label'       => __( 'Breadcrumb Type', 'winsome' ),
		'section'     => 'section_breadcrumb',
		'type'        => 'radio',
		'priority'    => 100,
		'choices'     => array(
			'disable' => esc_html__( 'Disable', 'winsome' ),
			'simple'  => esc_html__( 'Simple', 'winsome' ),
		),
	)
);

// Slider Section.
$wp_customize->add_section( 'section_slider',
	array(
		'title'      => __( 'Slider Options', 'winsome' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting slider_status.
$wp_customize->add_setting( 'slider_status',
	array(
		'default'           => $default['slider_status'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'winsome_sanitize_select',
	)
);
$wp_customize->add_control( 'slider_status',
	array(
		'label'       => __( 'Slider Status', 'winsome' ),
		'section'     => 'section_slider',
		'type'        => 'radio',
		'priority'    => 100,
		'choices'     => array(
			'disable' => esc_html__( 'Disable', 'winsome' ),
			'home'    => esc_html__( 'Multiple Slides', 'winsome' ),
		),
	)
);

$slider_number = 5;

for ( $i = 1; $i <= $slider_number; $i++ ) {
	//Slide Details
	$wp_customize->add_setting('slide_'.$i.'_info', 
		array(
			'sanitize_callback' => 'esc_attr',            
		)
	);

	$wp_customize->add_control( 
		new Winsome_Info( 
			$wp_customize, 
			'slide_'.$i.'_info', 
			array(
				'label' 			=> __('Slide Details', 'winsome'),
				'section' 			=> 'section_slider',
				'priority' 			=> 100,
				'active_callback' 	=> 'winsome_is_featured_slider_active',
			) 
		)
	);   

	$wp_customize->add_setting( 'slide_'.$i.'_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control( 'slide_'.$i.'_title',
		array(
			'label'    			=> __( 'Title', 'winsome' ),
			'section'  			=> 'section_slider',
			'type'     			=> 'text',
			'priority' 			=> 100,
			'active_callback' 	=> 'winsome_is_featured_slider_active',
		)
	);

	$wp_customize->add_setting( 'slide_'.$i.'_subtitle',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control( 'slide_'.$i.'_subtitle',
		array(
			'label'    			=> __( 'Sub Title', 'winsome' ),
			'section'  			=> 'section_slider',
			'type'     			=> 'text',
			'priority' 			=> 100,
			'active_callback' 	=> 'winsome_is_featured_slider_active',
		)
	);

	$wp_customize->add_setting('slider_'.$i.'_image',
	    array(
	        'sanitize_callback' => 'esc_url_raw',
	    )
	);

	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'slider_'.$i.'_image',
	        array(
	           'label'          	=> __( 'Upload image for the slider', 'winsome' ),
	           'type'           	=> 'image',
	           'section'        	=> 'section_slider',
	           'priority'       	=> 100,
	           'active_callback' 	=> 'winsome_is_featured_slider_active',
	        )
	    )
	);
}

	$wp_customize->add_setting('cta_info', 
		array(
			'sanitize_callback' => 'esc_attr',            
		)
	);

	$wp_customize->add_control( 
		new Winsome_Info( 
			$wp_customize, 
			'cta_info', 
			array(
				'label' 			=> __('Call to action button', 'winsome'),
				'section' 			=> 'section_slider',
				'priority' 			=> 100,
				'active_callback' 	=> 'winsome_is_featured_slider_active',
			) 
		)
	); 

	$wp_customize->add_setting( 'cta_text',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control( 'cta_text',
		array(
			'label'    			=> __( 'CTA Text', 'winsome' ),
			'section'  			=> 'section_slider',
			'type'     			=> 'text',
			'priority' 			=> 100,
			'active_callback' 	=> 'winsome_is_featured_slider_active',
		)
	);

	$wp_customize->add_setting( 'cta_url',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control( 'cta_url',
		array(
			'label'    			=> __( 'CTA Link', 'winsome' ),
			'section'  			=> 'section_slider',
			'type'     			=> 'text',
			'priority' 			=> 100,
			'active_callback' 	=> 'winsome_is_featured_slider_active',
		)
	); 

class Winsome_Info extends WP_Customize_Control {
    public $type = 'info';
    public $label = '';
    public function render_content() {
    ?>
        <h2 style="border:1px solid #ff9900; padding:5px; color:#ff9900; text-transform:uppercase; text-align: center; font-size: 15px; font-weight: normal;"><?php echo esc_html( $this->label ); ?></h2>
    <?php
    }
}  
